# sturgmapdemo


[![image](https://img.shields.io/pypi/v/sturgmapdemo.svg)](https://pypi.python.org/pypi/sturgmapdemo)
[![image](https://img.shields.io/conda/vn/conda-forge/sturgmapdemo.svg)](https://anaconda.org/conda-forge/sturgmapdemo)


**A python package demo for my real python package named sturgmap**


-   Free software: MIT License
-   Documentation: https://nathansturgill.github.io/sturgmapdemo
    

## Features

-   TODO
